" " "这是nester.py模块，提供了一个名为printf()的函数，函数的作用是打印列表，其中有可能包含（也有可能不包含）嵌套列表" " "

def printf (the_list):

    " " "参数是一个列表（可以嵌套也可以不嵌套)" " "
    for each in the_list:
        if isinstance(each,list):
            printf (each)
        else:
            print(each)





from distutils.core import setup
setup(
    name = 'nester_s',
    version = '1.0.0',
    py_modules= ['nester_s'],
    author = 'Tyzx',
    author_email = 'zstu_xd1110@163.com',
    url = 'http://blog.csdn.net/qq_40766258',
    description = 'A simple printer of nested lists',
    )
